==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/ServiceEntryListFluent.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import javax.validation.constraints.NotNull;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.Deprecated;
import javax.validation.Valid;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface ServiceEntryListFluent<A extends ServiceEntryListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A addToItems(int index,ServiceEntry item);
    public A setToItems(int index,ServiceEntry item);
    public A addToItems(ServiceEntry... items);
    public A addAllToItems(Collection<ServiceEntry> items);
    public A removeFromItems(ServiceEntry... items);
    public A removeAllFromItems(Collection<ServiceEntry> items);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<ServiceEntry> getItems();
    public List<ServiceEntry> buildItems();
    public ServiceEntry buildItem(int index);
    public ServiceEntry buildFirstItem();
    public ServiceEntry buildLastItem();
    public ServiceEntry buildMatchingItem(Predicate<ServiceEntryBuilder> predicate);
    public A withItems(List<ServiceEntry> items);
    public A withItems(ServiceEntry... items);
    public Boolean hasItems();
    public ServiceEntryListFluent.ItemsNested<A> addNewItem();
    public ServiceEntryListFluent.ItemsNested<A> addNewItemLike(ServiceEntry item);
    public ServiceEntryListFluent.ItemsNested<A> setNewItemLike(int index,ServiceEntry item);
    public ServiceEntryListFluent.ItemsNested<A> editItem(int index);
    public ServiceEntryListFluent.ItemsNested<A> editFirstItem();
    public ServiceEntryListFluent.ItemsNested<A> editLastItem();
    public ServiceEntryListFluent.ItemsNested<A> editMatchingItem(Predicate<ServiceEntryBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,String resourceVersion,String selfLink);

    public interface ItemsNested<N> extends Nested<N>,ServiceEntryFluent<ServiceEntryListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/ServiceEntryListFluent.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface ServiceEntryListFluent<A extends ServiceEntryListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,ServiceEntry item);
    public A setToItems(int index,ServiceEntry item);
    public A addToItems(ServiceEntry... items);
    public A addAllToItems(Collection<ServiceEntry> items);
    public A removeFromItems(ServiceEntry... items);
    public A removeAllFromItems(Collection<ServiceEntry> items);
    public A removeMatchingFromItems(Predicate<ServiceEntryBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<ServiceEntry> getItems();
    public List<ServiceEntry> buildItems();
    public ServiceEntry buildItem(int index);
    public ServiceEntry buildFirstItem();
    public ServiceEntry buildLastItem();
    public ServiceEntry buildMatchingItem(Predicate<ServiceEntryBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<ServiceEntryBuilder> predicate);
    public A withItems(List<ServiceEntry> items);
    public A withItems(ServiceEntry... items);
    public Boolean hasItems();
    public ServiceEntryListFluent.ItemsNested<A> addNewItem();
    public ServiceEntryListFluent.ItemsNested<A> addNewItemLike(ServiceEntry item);
    public ServiceEntryListFluent.ItemsNested<A> setNewItemLike(int index,ServiceEntry item);
    public ServiceEntryListFluent.ItemsNested<A> editItem(int index);
    public ServiceEntryListFluent.ItemsNested<A> editFirstItem();
    public ServiceEntryListFluent.ItemsNested<A> editLastItem();
    public ServiceEntryListFluent.ItemsNested<A> editMatchingItem(Predicate<ServiceEntryBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);

    public interface ItemsNested<N> extends Nested<N>,ServiceEntryFluent<ServiceEntryListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}


}
